@@ -71,28 +71,6 @@ class PullEvent(RepoEvents):
         RepoEvents.__init__(self, **kwargs)
         self.event_type = "PullEvent"
 
-
-class InvestmentKPI(EmbeddedDocument):
-    """The investment KPI total and sub-totals."""
-
-    total = FloatField(default=0.0)
-    features = FloatField(default=0.0)
-    defects = FloatField(default=0.0)
-    devops = FloatField(default=0.0)
-    debt = FloatField(default=0.0)
-
-    def __init__(self, load_dict, **kwargs):
-        EmbeddedDocument.__init__(self, **kwargs)
-        self.load(load_dict)
-
-    def load(self, load_dict):
-        self.total = load_dict["total"]
-        self.features = load_dict["features"]
-        self.defects = load_dict["defects"]
-        self.devops = load_dict["devops"]
-        self.debt = load_dict["debt"]
-
-
 class MaturityKPI(EmbeddedDocument):
     """The maturity KPI total and sub-totals."""
 
@@ -140,6 +118,14 @@ class RiskKPI(EmbeddedDocument):
 
     total = FloatField(default=0.0)
     secrets = FloatField(default=0.0)
+    auth = FloatField(default=0.0)
+    keys = FloatField(default=0.0)
+    compliance = FloatField(default=0.0)
+    delta_warning = FloatField(default=0.0) 
+    delta_errors = FloatField(default=0.0) 
+    devops_warnings = FloatField(default=0.0)
+    devops_errors = FloatField(default=0.0)
+
 
     def __init__(self, load_dict, **kwargs):
         EmbeddedDocument.__init__(self, **kwargs)
@@ -148,31 +134,16 @@ class RiskKPI(EmbeddedDocument):
     def load(self, load_dict):
         self.total = load_dict["total"]
         self.secrets = load_dict["secrets"]
-
-
-class VelocityKPI(EmbeddedDocument):
-    """The velocity KPI total and sub-totals."""
-
-    total = FloatField(default=0.0)
-    commit = FloatField(default=0.0)
-    merge_frequency = FloatField(default=0.0)
-
-    def __init__(self, load_dict, **kwargs):
-        EmbeddedDocument.__init__(self, **kwargs)
-        self.load(load_dict)
-
-    def load(self, load_dict):
-        self.total = load_dict["total"]
-        self.tags = load_dict["commit"]
-        self.identifiers = load_dict["merge_frequency"]
-
+        self.auth = load_dict["auth"]
+        self.keys = load_dict["keys"]
+        self.compliance = load_dict["compliance"]
 
 class InfrastructureKPI(EmbeddedDocument):
     """The infrastructure KPI total and sub-totals."""
 
     total = FloatField(default=0.0)
     tags = FloatField(default=0.0)
-    identifiers = FloatField(default=0.0)
+    networking = FloatField(default=0.0)
     compute_resources = FloatField(default=0.0)
     environments = FloatField(default=0.0)
 
@@ -183,10 +154,41 @@ class InfrastructureKPI(EmbeddedDocument):
     def load(self, load_dict):
         self.total = load_dict["total"]
         self.tags = load_dict["tags"]
-        self.identifiers = load_dict["identifiers"]
+        self.networking = load_dict["networking"]
         self.compute_resources = load_dict["compute_resources"]
         self.environments = load_dict["environments"]
 
+class VelocityKPI(EmbeddedDocument):
+    """The velocity KPI total and sub-totals."""
+
+    pr_size = FloatField(default=0.0)
+    pr_duration = FloatField(default=0.0)
+    pr_commit_count = FloatField(default=0.0)
+    commit_freq = FloatField(default=0.0)
+    actors = ListField()
+    comment_percent = FloatField()
+    space_percent = FloatField()
+
+
+class InvestmentKPI(EmbeddedDocument):
+    """The investment KPI total and sub-totals."""
+
+    total = FloatField(default=0.0)
+    features = FloatField(default=0.0)
+    defects = FloatField(default=0.0)
+    devops = FloatField(default=0.0)
+    debt = FloatField(default=0.0)
+
+    def __init__(self, load_dict, **kwargs):
+        EmbeddedDocument.__init__(self, **kwargs)
+        self.load(load_dict)
+
+    def load(self, load_dict):
+        self.total = load_dict["total"]
+        self.features = load_dict["features"]
+        self.defects = load_dict["defects"]
+        self.devops = load_dict["devops"]
+        self.debt = load_dict["debt"]
 
 class CommitEvent(RepoEvents):
     """The GitHub commit events model.
@@ -206,15 +208,13 @@ class CommitEvent(RepoEvents):
     total = IntField(default=0)
     commit_files = ListField()
 
-    # Crawler flags
-    actor = DictField()
-    aspect_flags = ListField()
-    filename_flags = ListField()
-    files = ListField()
+    # Category and Tokens
+    category =  DictField()
+    file_count = DictField()
+    #tokens = DictField()
+    #files = ListField()
 
     # Linter fields
-    linter_warnings_total = IntField(default=0)
-    linter_errors_total = IntField(default=0)
     linter_events = EmbeddedDocumentListField(LinterScanEvent)
 
     # Analysis fields
@@ -235,15 +235,18 @@ class PipelineRun(Document):
     repo = StringField(max_length=200)
     branch = StringField(max_length=50)
     buildnumber = IntField(required=True)
-    building = BooleanField()
+    building = BooleanField(required=True)
     durationMillis = IntField()
     result = StringField(max_length=50)
-    timestamp = IntField(max_length=50)
-    url = StringField(max_length=50)
+    timestamp = DateTimeField()
+    url = StringField(max_length=256)
     fail_stage = StringField(max_length=50)
     fail_logs = StringField(max_length=10000)
     tags = ListField(StringField(max_length=30))
-    meta = {'indexes': ['name']}
+    meta = {
+        'indexes': [
+            'name'
+        ]}
 
 class Group(Document):
     name = StringField(max_length=120, primary_key=True, required=True)
@@ -252,3 +255,25 @@ class Group(Document):
 class Set(Document):
     name = StringField(max_length=120, primary_key=True, required=True)
     children = ListField(StringField(max_length=120))
+
+class JiraIssue(Document):
+    issue_id            = StringField()
+    issue_key           = StringField()
+    issuetype_name      = StringField()
+    parent_issue_key    = StringField()
+    parent_issue_id     = StringField()
+    project_id          = StringField()
+    project_key         = StringField()
+    project_name        = StringField()
+    resolution_name     = StringField()
+    resolution_date     = DateTimeField()
+    created             = DateTimeField()
+    priority_name       = StringField()
+    priority_id         = StringField()
+    status_name         = StringField()
+    assignee_key        = StringField()
+    story_points        = FloatField()
+    labels              = ListField(StringField())
+    work_begin_date     = DateTimeField()
+    work_completed_date = DateTimeField()
+    
\ No newline at end of file
